// 16 august 2014

package ui

import (
	"bytes"
	"fmt"
	"image"
	"image/draw"
	_ "image/png"
)

type icon struct {
	Bool bool
	Icon *image.RGBA
	Name string
}

var firstimg *image.RGBA

func readIcons() []icon {
	out := make([]icon, len(icons))
	for i := range icons {
		r := bytes.NewReader(icons[i].data)
		png, _, err := image.Decode(r)
		if err != nil {
			panic(fmt.Errorf("error loading image %d (%q): %v", i, icons[i].name, err))
		}
		img := image.NewRGBA(png.Bounds())
		draw.Draw(img, img.Rect, png, image.ZP, draw.Src)
		if firstimg == nil {
			firstimg = img
		}
		out[i].Icon = img
		out[i].Name = icons[i].name
	}
	return out
}

func tileImage(times int) *image.RGBA {
	dx := firstimg.Rect.Dx()
	dy := firstimg.Rect.Dy()
	res := image.NewRGBA(image.Rect(0, 0, times*dx, times*dy))
	r := image.Rect(0, 0, dx, dy)
	for y := 0; y < times; y++ {
		rr := r.Add(image.Pt(0, y*dy))
		for x := 0; x < times; x++ {
			draw.Draw(res, rr, firstimg, image.ZP, draw.Src)
			rr = rr.Add(image.Pt(dx, 0))
		}
	}
	return res
}

var icons = []struct {
	data []byte
	name string
}{
	{__16x16_categories_applications_accessories_png, "16x16/categories/applications-accessories.png"},
	{__16x16_places_folder_png, "16x16/places/folder.png"},
	{__16x16_mimetypes_x_office_spreadsheet_png, "16x16/mimetypes/x-office-spreadsheet.png"},
	{__32x32_categories_applications_accessories_png, "32x32/categories/applications-accessories.png"},
	{__32x32_places_folder_png, "32x32/places/folder.png"},
	{__32x32_mimetypes_x_office_spreadsheet_png, "32x32/mimetypes/x-office-spreadsheet.png"},
}

// from http://tango.freedesktop.org/releases/tango-icon-theme-0.8.90.tar.gz, which is public domain

var __16x16_categories_applications_accessories_png = []byte{
	0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
	0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
	0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x00,
	0x06, 0x62, 0x4b, 0x47, 0x44, 0x00, 0xff, 0x00, 0xff, 0x00, 0xff, 0xa0,
	0xbd, 0xa7, 0x93, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00,
	0x00, 0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18,
	0x00, 0x00, 0x00, 0x07, 0x74, 0x49, 0x4d, 0x45, 0x07, 0xd5, 0x0b, 0x1c,
	0x17, 0x38, 0x22, 0x38, 0xae, 0xb6, 0xe0, 0x00, 0x00, 0x03, 0x36, 0x49,
	0x44, 0x41, 0x54, 0x38, 0xcb, 0x5d, 0x93, 0x4b, 0x4c, 0x5c, 0x75, 0x14,
	0xc6, 0xbf, 0xff, 0x63, 0xe6, 0xde, 0x79, 0x80, 0x73, 0x41, 0x60, 0x66,
	0x80, 0xa2, 0x13, 0x04, 0x9a, 0x49, 0x53, 0x13, 0x17, 0xc5, 0x57, 0xdd,
	0x18, 0x4a, 0xd2, 0x8d, 0xa9, 0x55, 0x1b, 0x1f, 0xab, 0x36, 0xc1, 0x54,
	0x6b, 0xd5, 0xd2, 0x66, 0x48, 0x43, 0x1a, 0x62, 0xa2, 0x0d, 0x94, 0x58,
	0x9b, 0x34, 0xac, 0x4c, 0x88, 0x8f, 0x85, 0x1b, 0x5c, 0x11, 0x12, 0xbb,
	0xa8, 0xa6, 0x34, 0x5d, 0x18, 0xb5, 0x75, 0x0c, 0x1d, 0xa8, 0x34, 0xf2,
	0x98, 0x29, 0x65, 0x18, 0xc6, 0x0e, 0x33, 0x70, 0xe7, 0xce, 0xfd, 0xff,
	0x8f, 0x1b, 0xc0, 0x49, 0xbf, 0xd5, 0x39, 0xdf, 0xc9, 0xf7, 0xcb, 0x49,
	0x4e, 0x0e, 0xc3, 0xb6, 0x46, 0x46, 0x2f, 0xf6, 0x02, 0xf8, 0xce, 0x34,
	0xcd, 0x87, 0xa7, 0x3e, 0xf8, 0x38, 0x8e, 0x2a, 0x8d, 0x8c, 0x5e, 0x1c,
	0x93, 0x52, 0xbe, 0xf5, 0xc9, 0xe9, 0xfe, 0xba, 0x6a, 0x7f, 0x7a, 0x1c,
	0xef, 0xf1, 0x9d, 0x46, 0x08, 0x31, 0xf1, 0xe1, 0xc9, 0xd3, 0x96, 0x6d,
	0xdb, 0x8b, 0x57, 0xc7, 0xae, 0x0c, 0xee, 0xf8, 0x97, 0xbf, 0x1a, 0xcd,
	0x1c, 0xea, 0xe9, 0xed, 0x03, 0x70, 0xe7, 0xb1, 0xf0, 0xcb, 0x00, 0xbe,
	0xde, 0x05, 0x28, 0xa5, 0xcc, 0x7b, 0xf3, 0xb3, 0xfc, 0xc4, 0xf1, 0xbe,
	0x1e, 0xa5, 0xd4, 0x7e, 0x00, 0x18, 0xbe, 0xf4, 0xc5, 0x2b, 0xd1, 0xe6,
	0x68, 0xa4, 0x58, 0xda, 0x60, 0x5a, 0xeb, 0xee, 0xaa, 0x70, 0x3b, 0xe3,
	0x62, 0x92, 0x31, 0xe1, 0xd9, 0x05, 0x70, 0xce, 0x4b, 0x0b, 0x0b, 0xff,
	0xc0, 0x34, 0x0c, 0x56, 0x2e, 0x97, 0xe3, 0x57, 0xc7, 0xae, 0x0c, 0x4a,
	0x29, 0xaf, 0xc5, 0x62, 0x31, 0xac, 0x3c, 0x58, 0xd1, 0x5a, 0xeb, 0xf9,
	0xed, 0xb0, 0xc5, 0x85, 0xb8, 0xde, 0xd1, 0xfd, 0x69, 0x50, 0x78, 0x6a,
	0x54, 0xf5, 0x06, 0x3d, 0xa9, 0x54, 0x0a, 0xcb, 0xe9, 0x25, 0x76, 0xe2,
	0x78, 0x5f, 0xa7, 0x6d, 0xdb, 0xef, 0x77, 0x75, 0x75, 0x79, 0x18, 0x38,
	0xe6, 0xef, 0xcf, 0x03, 0xc0, 0x0f, 0xd3, 0xe3, 0xf0, 0x70, 0x21, 0xa6,
	0x5a, 0xe3, 0x47, 0x9b, 0xea, 0x5a, 0x0e, 0x31, 0x00, 0xd8, 0x05, 0x9c,
	0xeb, 0x1f, 0xb8, 0xc5, 0x39, 0x5f, 0x9c, 0x9b, 0x9b, 0x85, 0x69, 0x98,
	0xcc, 0x0a, 0x59, 0x51, 0xd2, 0x40, 0x76, 0x6d, 0x55, 0x03, 0x98, 0x3c,
	0x7b, 0x26, 0xf1, 0x19, 0x17, 0x62, 0xbc, 0xbe, 0xf9, 0xc0, 0xfe, 0x68,
	0xc7, 0x9b, 0x1e, 0x50, 0x09, 0x44, 0xf4, 0x3f, 0x00, 0x00, 0xb4, 0xd6,
	0x47, 0x66, 0xee, 0xce, 0xd0, 0xea, 0xea, 0x0a, 0x5c, 0xe5, 0x62, 0x63,
	0xa3, 0x80, 0x64, 0x32, 0xe9, 0x00, 0x18, 0xba, 0xf9, 0x0d, 0x3f, 0xef,
	0x0f, 0xb5, 0xbd, 0x16, 0x7b, 0xee, 0x94, 0xe9, 0x16, 0x27, 0xa1, 0xdd,
	0x0d, 0x00, 0x8f, 0x01, 0xce, 0x9e, 0x49, 0xfc, 0xc6, 0x39, 0xff, 0x76,
	0x76, 0x2e, 0xa5, 0x43, 0xa1, 0x10, 0x32, 0x0f, 0x32, 0x44, 0x44, 0xe3,
	0xcf, 0xd7, 0x27, 0x9e, 0xf2, 0x78, 0x6b, 0xcf, 0x77, 0x76, 0x0f, 0xf8,
	0xdd, 0xd2, 0x34, 0x2a, 0x5b, 0x8b, 0xd0, 0xca, 0x06, 0x88, 0xc0, 0xaa,
	0x01, 0x13, 0xe1, 0xf0, 0xa8, 0x4b, 0x74, 0xd2, 0xcd, 0xe7, 0x4d, 0xb8,
	0x2e, 0x9e, 0x0e, 0x37, 0x21, 0x4d, 0x7a, 0x33, 0x78, 0xd0, 0xf6, 0xbe,
	0x70, 0x69, 0x40, 0x4a, 0xbe, 0x86, 0x62, 0xee, 0x06, 0x0c, 0xd3, 0x84,
	0x37, 0xf4, 0x06, 0x6e, 0xff, 0x94, 0x50, 0x02, 0x00, 0x26, 0x22, 0x91,
	0xc1, 0x23, 0x95, 0xca, 0xf5, 0x4e, 0xcb, 0xea, 0x0e, 0x09, 0x21, 0x95,
	0x72, 0xa9, 0xec, 0x3a, 0xa8, 0x0b, 0xd4, 0xb0, 0x46, 0xd3, 0xf0, 0x18,
	0xcb, 0x26, 0xff, 0x75, 0x78, 0x0a, 0x9e, 0xc6, 0x1c, 0xb2, 0x5b, 0x77,
	0x11, 0x6a, 0x6c, 0x02, 0xf7, 0xb6, 0x63, 0xf5, 0xfe, 0xcf, 0xc4, 0x7f,
	0x8c, 0x46, 0xdf, 0x75, 0x72, 0xb9, 0xa1, 0xce, 0x70, 0x58, 0xcf, 0x2c,
	0x2d, 0x5d, 0x2b, 0x6c, 0x6d, 0x3a, 0xf9, 0xc2, 0x06, 0xf7, 0x1d, 0xd6,
	0x2d, 0x42, 0x32, 0xfc, 0x6b, 0x97, 0x50, 0x88, 0x99, 0x68, 0x6f, 0xa8,
	0x47, 0x32, 0x31, 0x87, 0xfc, 0x94, 0x44, 0xc5, 0x71, 0xa0, 0xdd, 0x32,
	0x08, 0x04, 0xee, 0x3a, 0xce, 0xf0, 0xbe, 0xd6, 0x56, 0x4a, 0x2d, 0x2f,
	0x5f, 0x38, 0xa6, 0x54, 0x6f, 0xad, 0xe9, 0x53, 0xc2, 0xe7, 0x53, 0x8d,
	0xaf, 0xf3, 0xef, 0xff, 0xce, 0xac, 0x20, 0x18, 0x0c, 0x20, 0xfe, 0x65,
	0x03, 0xf2, 0x2f, 0xad, 0xb9, 0x7b, 0xa3, 0x11, 0x2a, 0xde, 0xf0, 0x42,
	0x55, 0x2a, 0x70, 0xdd, 0x4d, 0x80, 0x08, 0x1c, 0xe5, 0x72, 0xbd, 0xe3,
	0x38, 0xea, 0x98, 0x52, 0x9f, 0x4f, 0x06, 0x02, 0x97, 0x3d, 0x52, 0x9a,
	0xc2, 0x42, 0xc1, 0x6f, 0xb5, 0x1f, 0x08, 0x3d, 0xbb, 0x07, 0x7e, 0x92,
	0xb8, 0x37, 0xf4, 0x17, 0xcc, 0x57, 0xb7, 0x24, 0x18, 0x31, 0x5d, 0xd0,
	0x70, 0x1d, 0x07, 0xaa, 0xb2, 0x09, 0x80, 0x20, 0xe1, 0xf5, 0x66, 0x82,
	0x7e, 0xff, 0x9e, 0xdb, 0x6d, 0x6d, 0x65, 0xad, 0xb5, 0x9c, 0x59, 0x4b,
	0x17, 0x9b, 0x2f, 0x3c, 0xe1, 0x6f, 0xd9, 0x7b, 0xd4, 0x08, 0x9c, 0xfb,
	0x05, 0xc9, 0x8f, 0xfe, 0x40, 0xc7, 0x9d, 0x30, 0x2a, 0xbf, 0xd7, 0x40,
	0x6b, 0x82, 0xac, 0x95, 0x50, 0xda, 0xdd, 0x06, 0x00, 0xe2, 0x6d, 0xcb,
	0xca, 0xa5, 0xd7, 0xd7, 0x5f, 0x5c, 0x77, 0x1c, 0x99, 0x67, 0xc4, 0xc2,
	0xfd, 0x5a, 0x3c, 0x73, 0xf8, 0x1d, 0x83, 0x73, 0x0f, 0x8c, 0x86, 0x27,
	0x61, 0x44, 0xeb, 0x90, 0x5e, 0xc8, 0x22, 0x9b, 0x2d, 0xe0, 0x91, 0x57,
	0x21, 0x3e, 0x72, 0x10, 0xbe, 0x48, 0x0c, 0x44, 0x0c, 0x8f, 0x1e, 0xfe,
	0x49, 0xac, 0xea, 0x41, 0xf6, 0x01, 0xb8, 0xc5, 0x98, 0x34, 0x85, 0xf4,
	0x3b, 0x00, 0x01, 0x44, 0xdb, 0x53, 0xda, 0x3d, 0x35, 0xed, 0xd4, 0x44,
	0x50, 0xca, 0xf6, 0xfd, 0x07, 0x11, 0xa6, 0x73, 0x42, 0xc7, 0xee, 0xef,
	0xaa, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60,
	0x82,
}

var __16x16_places_folder_png = []byte{
	0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
	0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
	0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x00,
	0x04, 0x73, 0x42, 0x49, 0x54, 0x08, 0x08, 0x08, 0x08, 0x7c, 0x08, 0x64,
	0x88, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00, 0x0d,
	0xd7, 0x00, 0x00, 0x0d, 0xd7, 0x01, 0x42, 0x28, 0x9b, 0x78, 0x00, 0x00,
	0x00, 0x19, 0x74, 0x45, 0x58, 0x74, 0x53, 0x6f, 0x66, 0x74, 0x77, 0x61,
	0x72, 0x65, 0x00, 0x77, 0x77, 0x77, 0x2e, 0x69, 0x6e, 0x6b, 0x73, 0x63,
	0x61, 0x70, 0x65, 0x2e, 0x6f, 0x72, 0x67, 0x9b, 0xee, 0x3c, 0x1a, 0x00,
	0x00, 0x01, 0xc2, 0x49, 0x44, 0x41, 0x54, 0x38, 0x8d, 0xa5, 0x90, 0x31,
	0x6b, 0x93, 0x51, 0x14, 0x86, 0x9f, 0x73, 0xef, 0x57, 0x2c, 0x29, 0xe2,
	0xe0, 0x10, 0xba, 0x14, 0x1c, 0x9c, 0x32, 0x76, 0xeb, 0x2e, 0x99, 0x1c,
	0x82, 0xd0, 0xd5, 0x5f, 0xa0, 0xbb, 0xd0, 0x3f, 0xe0, 0xe2, 0x56, 0x57,
	0xff, 0x87, 0x28, 0xc4, 0xb9, 0x60, 0xc4, 0x59, 0x29, 0x8a, 0x24, 0x92,
	0x50, 0x69, 0xbf, 0x26, 0x25, 0xdf, 0xbd, 0xe7, 0x9e, 0xe3, 0x90, 0x26,
	0x36, 0x58, 0x5a, 0xc1, 0x77, 0x39, 0xdc, 0x7b, 0xcf, 0x79, 0xee, 0x79,
	0x5f, 0xe9, 0x76, 0xbb, 0xfc, 0x8f, 0xaa, 0xdd, 0xdd, 0xdd, 0x37, 0xee,
	0xfe, 0xf8, 0x9a, 0xb7, 0x0b, 0x77, 0x7f, 0x32, 0x18, 0x0c, 0x8e, 0x6e,
	0x04, 0x98, 0x59, 0xaf, 0xd7, 0xeb, 0xdd, 0x33, 0x33, 0xcc, 0x0c, 0x77,
	0x07, 0xe0, 0xf4, 0xf4, 0xf4, 0x7e, 0xbf, 0xdf, 0x3f, 0xec, 0x74, 0x3a,
	0xcf, 0x97, 0xcd, 0x39, 0x67, 0x42, 0x08, 0x65, 0x38, 0x1c, 0x7e, 0xac,
	0xeb, 0xba, 0x00, 0x54, 0x39, 0x67, 0x57, 0x55, 0x26, 0x93, 0x09, 0xa5,
	0x94, 0x15, 0x24, 0x84, 0xc0, 0xf6, 0xf6, 0x76, 0x07, 0x78, 0xbb, 0x84,
	0x02, 0x4c, 0xa7, 0xd3, 0xaa, 0x94, 0xf2, 0xaa, 0xae, 0xeb, 0x83, 0x2b,
	0x80, 0x8c, 0xaa, 0x62, 0x66, 0x6b, 0x90, 0x76, 0xbb, 0xdd, 0xda, 0xdc,
	0xdc, 0xa4, 0xd5, 0x6a, 0x11, 0x63, 0x24, 0x84, 0xc0, 0x68, 0x34, 0x62,
	0x3c, 0x1e, 0x3f, 0x5c, 0x59, 0x50, 0x55, 0x53, 0x2d, 0x1c, 0x7e, 0x48,
	0xcc, 0x9a, 0x3f, 0x3f, 0x81, 0x00, 0xe0, 0xcc, 0x81, 0xf9, 0xea, 0xd6,
	0x3d, 0x00, 0x7b, 0xfb, 0xec, 0xec, 0xed, 0xc7, 0x18, 0xbe, 0x55, 0x39,
	0x67, 0x4f, 0x29, 0x31, 0x6d, 0x9c, 0x97, 0xcf, 0x1e, 0x21, 0x72, 0xd9,
	0x78, 0x35, 0x29, 0x5f, 0x3b, 0x01, 0x90, 0xd4, 0x39, 0x78, 0xfd, 0x7e,
	0xa7, 0x4a, 0x29, 0x99, 0xaa, 0x02, 0x4e, 0x0c, 0xf0, 0xe9, 0xf8, 0xec,
	0xea, 0x02, 0xcb, 0xb2, 0x9e, 0x7c, 0x14, 0x1e, 0xb4, 0xb7, 0x40, 0xdc,
	0x2b, 0x55, 0x25, 0xe7, 0x8c, 0x88, 0x10, 0x83, 0x10, 0xe3, 0x75, 0x23,
	0xeb, 0xca, 0x6a, 0xb8, 0x39, 0x82, 0x78, 0x95, 0x73, 0xb6, 0x9c, 0x33,
	0xb8, 0x13, 0x44, 0xd8, 0xb8, 0x01, 0xa0, 0xc5, 0x69, 0xb2, 0x51, 0xcc,
	0x09, 0x41, 0x00, 0x16, 0x00, 0xd5, 0xc5, 0x06, 0xf3, 0x54, 0x08, 0x80,
	0xf9, 0xa2, 0xb9, 0xb8, 0x63, 0xe6, 0x98, 0x3b, 0x59, 0x17, 0x75, 0x69,
	0xa1, 0x49, 0xb6, 0x02, 0xb8, 0x6a, 0x41, 0xa4, 0x62, 0x52, 0x37, 0x0c,
	0x7f, 0xcd, 0x69, 0xd4, 0x6e, 0xb4, 0x50, 0x45, 0x61, 0x72, 0x36, 0x5f,
	0x00, 0x54, 0xd5, 0x52, 0x4a, 0xe0, 0x91, 0x2f, 0xa3, 0x73, 0x4e, 0xa6,
	0x0d, 0x7f, 0x67, 0xbe, 0xae, 0x18, 0x84, 0x9f, 0x67, 0x97, 0x16, 0x44,
	0xc4, 0xcc, 0x0c, 0x11, 0xa1, 0xc9, 0x46, 0xeb, 0x4e, 0x75, 0x6b, 0x88,
	0x22, 0xc2, 0x45, 0x52, 0x80, 0x52, 0xb9, 0x3b, 0xc7, 0x27, 0x86, 0x08,
	0x7c, 0xfe, 0x3a, 0xba, 0x75, 0x78, 0xa9, 0xd9, 0x6c, 0x8e, 0xc0, 0x51,
	0x65, 0x1b, 0x5b, 0xfd, 0x77, 0xc7, 0x77, 0x9f, 0x82, 0xf3, 0xe3, 0xfb,
	0xf8, 0x9f, 0x01, 0x22, 0x8c, 0x45, 0xc2, 0x8b, 0xdf, 0x47, 0x16, 0x21,
	0x9e, 0x1c, 0x63, 0xa7, 0x31, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e,
	0x44, 0xae, 0x42, 0x60, 0x82,
}

var __16x16_mimetypes_x_office_spreadsheet_png = []byte{
	0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
	0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
	0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x00,
	0x06, 0x62, 0x4b, 0x47, 0x44, 0x00, 0xff, 0x00, 0xff, 0x00, 0xff, 0xa0,
	0xbd, 0xa7, 0x93, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00,
	0x00, 0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18,
	0x00, 0x00, 0x00, 0x07, 0x74, 0x49, 0x4d, 0x45, 0x07, 0xd5, 0x04, 0x16,
	0x14, 0x0d, 0x09, 0xd9, 0x88, 0x44, 0xfa, 0x00, 0x00, 0x02, 0x4d, 0x49,
	0x44, 0x41, 0x54, 0x38, 0xcb, 0x95, 0x92, 0xdf, 0x4b, 0x53, 0x61, 0x18,
	0xc7, 0x3f, 0x67, 0x9b, 0x6e, 0x7a, 0xd6, 0xfc, 0x55, 0xe0, 0x59, 0x8a,
	0x95, 0x71, 0x08, 0x52, 0x21, 0x91, 0x2c, 0x8a, 0x0a, 0x94, 0x11, 0x14,
	0x78, 0x21, 0x99, 0x14, 0x81, 0xdd, 0x48, 0x7f, 0x45, 0x63, 0x5d, 0x75,
	0x1b, 0x34, 0xd0, 0x9b, 0x52, 0x83, 0x0a, 0xad, 0x0b, 0x43, 0x72, 0xd0,
	0x85, 0x14, 0x14, 0x68, 0x77, 0x39, 0xcd, 0x6c, 0x94, 0x0c, 0xf4, 0x48,
	0x4d, 0x5b, 0x5b, 0x4b, 0xcf, 0x39, 0x3b, 0xef, 0xe9, 0x62, 0x3f, 0xec,
	0xd7, 0x2e, 0x7c, 0xae, 0xbe, 0x2f, 0xef, 0xf3, 0xfd, 0xbc, 0xdf, 0xf7,
	0x7d, 0x5e, 0x69, 0x78, 0x78, 0xf8, 0xc9, 0xfa, 0xfa, 0x7a, 0x2f, 0xbb,
	0xab, 0xcb, 0xc1, 0x60, 0x70, 0x1c, 0x80, 0x50, 0x28, 0x64, 0xef, 0xb6,
	0x42, 0xa1, 0x90, 0x5d, 0x20, 0xb9, 0x0a, 0x22, 0x12, 0x89, 0xe4, 0x95,
	0x84, 0xa6, 0x69, 0xf8, 0xfd, 0x0a, 0x00, 0x9a, 0xa6, 0xa1, 0x28, 0xfe,
	0xbc, 0x5e, 0x63, 0x60, 0x60, 0xe0, 0x8f, 0x28, 0x45, 0x80, 0xa6, 0x69,
	0x48, 0x52, 0x0e, 0x20, 0x49, 0xb9, 0xf5, 0xce, 0xde, 0x5a, 0xc9, 0xbb,
	0x14, 0x01, 0x8a, 0x5f, 0xc1, 0x2b, 0x7b, 0x01, 0x88, 0xc5, 0x62, 0xf4,
	0xf4, 0xf4, 0x00, 0x10, 0x8d, 0x46, 0x69, 0x69, 0x6d, 0x41, 0xb2, 0x25,
	0xe6, 0xa3, 0xf3, 0xa5, 0x01, 0x86, 0x6e, 0x90, 0x21, 0x83, 0x84, 0x04,
	0x40, 0x2a, 0x95, 0x22, 0x2f, 0x49, 0x7f, 0x4f, 0x91, 0x8f, 0x57, 0x1a,
	0xe0, 0x71, 0xbb, 0x91, 0xbd, 0x5e, 0x0a, 0xaf, 0xe3, 0xf3, 0x55, 0x15,
	0xfc, 0xf8, 0xaa, 0x76, 0x74, 0x49, 0xc0, 0xb6, 0xae, 0xe7, 0x4f, 0xcc,
	0xb5, 0x7e, 0x8c, 0x3c, 0x67, 0xf5, 0xee, 0x1d, 0xb6, 0x16, 0x16, 0x89,
	0xa7, 0x33, 0xb9, 0x26, 0xb9, 0x82, 0xc9, 0xb6, 0x56, 0xbc, 0x6d, 0xed,
	0xff, 0x49, 0xe0, 0xf1, 0x20, 0xcb, 0x32, 0x00, 0xf6, 0xe8, 0x3d, 0x3e,
	0xcd, 0xcd, 0xd1, 0x74, 0xe5, 0x22, 0x65, 0x9d, 0x2a, 0xc2, 0x21, 0x91,
	0x15, 0x02, 0xc3, 0x14, 0x48, 0x0e, 0x0f, 0x4d, 0xcf, 0xa6, 0x78, 0x74,
	0xbc, 0xe3, 0x65, 0xff, 0xec, 0xdb, 0xfe, 0x22, 0x40, 0xd7, 0x75, 0x00,
	0x36, 0x1e, 0x8c, 0x51, 0xb3, 0xb2, 0x4c, 0xc3, 0x8d, 0x3e, 0xb2, 0xe9,
	0x24, 0xc9, 0xf8, 0x2a, 0xa6, 0x10, 0x18, 0x96, 0x8d, 0xb3, 0xaa, 0x16,
	0x53, 0x08, 0xac, 0x4e, 0x15, 0xe7, 0xd2, 0xea, 0x99, 0x11, 0xf5, 0xf0,
	0xed, 0x22, 0xc0, 0xed, 0x76, 0x23, 0xcb, 0x32, 0x89, 0xc8, 0x34, 0xfb,
	0xaf, 0x9e, 0xe7, 0x47, 0x3c, 0x56, 0x34, 0x9a, 0x42, 0xf0, 0xa1, 0xfe,
	0x10, 0x9b, 0x86, 0x0b, 0x53, 0x64, 0x31, 0x24, 0x0b, 0xef, 0xb1, 0x7a,
	0xd4, 0xa7, 0x93, 0x7d, 0xff, 0x24, 0xb0, 0x37, 0xbf, 0x61, 0x19, 0x5b,
	0xe8, 0xd6, 0x8e, 0x59, 0x52, 0xca, 0xd9, 0xd3, 0xe1, 0x26, 0xfc, 0xb5,
	0x0b, 0xc3, 0xd4, 0x51, 0x6b, 0xbd, 0x08, 0xcb, 0xe4, 0xe8, 0xe8, 0x43,
	0x8f, 0xe3, 0xef, 0x04, 0x66, 0x75, 0x0d, 0xce, 0x7d, 0x0d, 0xe0, 0xab,
	0x41, 0x17, 0x16, 0xba, 0x25, 0x70, 0xaa, 0x95, 0x34, 0x37, 0xa7, 0xa9,
	0xcf, 0xae, 0x71, 0xb2, 0x71, 0x2f, 0x5f, 0x52, 0x29, 0x7c, 0x2b, 0xef,
	0xc9, 0x78, 0x3c, 0xdb, 0xc5, 0x04, 0x81, 0x40, 0x20, 0x37, 0x8d, 0xc1,
	0x41, 0xde, 0xdd, 0x1f, 0xe3, 0xe0, 0xf5, 0x5e, 0xea, 0x0e, 0x1c, 0xc1,
	0x76, 0xb9, 0xa8, 0x3e, 0x5d, 0x87, 0xa8, 0x70, 0x10, 0xec, 0x90, 0x78,
	0xfc, 0x39, 0x4d, 0x63, 0x7c, 0x91, 0xf6, 0xc9, 0x09, 0x2a, 0x55, 0x75,
	0x5c, 0x0a, 0x87, 0xc3, 0x53, 0x89, 0x44, 0xe2, 0xc2, 0xef, 0xb3, 0xad,
	0x9d, 0x99, 0x41, 0x7e, 0xf3, 0x1a, 0xf3, 0xdc, 0x09, 0xca, 0x1a, 0xaa,
	0xf1, 0x9c, 0xb5, 0xd1, 0x0d, 0x41, 0x66, 0xc3, 0x64, 0x7a, 0x4a, 0xd0,
	0x33, 0xfb, 0x8a, 0x0a, 0x55, 0x7d, 0x71, 0x6d, 0x61, 0x21, 0x50, 0xea,
	0x7f, 0x30, 0xd2, 0xdd, 0x7d, 0x49, 0x5f, 0x5a, 0xba, 0xe9, 0x4e, 0x26,
	0x55, 0xe7, 0xcf, 0x4c, 0xb9, 0x6d, 0x83, 0x90, 0x65, 0xc3, 0xa5, 0x28,
	0xcb, 0x07, 0xbb, 0xba, 0x6e, 0x9d, 0x1a, 0x1a, 0x9a, 0x00, 0xf8, 0x05,
	0xf4, 0xf5, 0x23, 0xe9, 0x30, 0xeb, 0x2d, 0xf9, 0x00, 0x00, 0x00, 0x00,
	0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
}

var __32x32_categories_applications_accessories_png = []byte{
	0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
	0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x20,
	0x08, 0x06, 0x00, 0x00, 0x00, 0x73, 0x7a, 0x7a, 0xf4, 0x00, 0x00, 0x00,
	0x04, 0x73, 0x42, 0x49, 0x54, 0x08, 0x08, 0x08, 0x08, 0x7c, 0x08, 0x64,
	0x88, 0x00, 0x00, 0x08, 0x66, 0x49, 0x44, 0x41, 0x54, 0x58, 0x85, 0xcd,
	0x97, 0x7b, 0x70, 0x54, 0xd5, 0x1d, 0xc7, 0xbf, 0xe7, 0x9c, 0xfb, 0xd8,
	0x57, 0x36, 0x4b, 0xb2, 0xcb, 0x12, 0x24, 0x04, 0x08, 0x41, 0x9e, 0x85,
	0x00, 0x2d, 0x10, 0x71, 0x24, 0xf2, 0x68, 0x67, 0x64, 0xa0, 0x58, 0xed,
	0xbb, 0xb4, 0x5a, 0x19, 0x2d, 0x4a, 0x18, 0x1e, 0x82, 0x05, 0x9c, 0x59,
	0x0d, 0x2a, 0x82, 0xe3, 0x28, 0x1d, 0x5b, 0x69, 0x61, 0x04, 0x44, 0x0a,
	0x8c, 0x8f, 0x62, 0x47, 0x0a, 0x33, 0x3c, 0x85, 0x20, 0x52, 0x85, 0x28,
	0x98, 0x28, 0x12, 0x1e, 0x9b, 0x40, 0x08, 0xc9, 0xe6, 0xb1, 0x8f, 0xec,
	0xde, 0xc7, 0x39, 0xa7, 0x7f, 0x24, 0x4b, 0x13, 0x12, 0x20, 0xfe, 0xd5,
	0xfe, 0x66, 0x7e, 0x73, 0xce, 0xde, 0xfd, 0x9e, 0xdf, 0xef, 0x73, 0x7f,
	0xe7, 0x9e, 0x73, 0xcf, 0x05, 0xfe, 0x07, 0x76, 0x74, 0x33, 0x9e, 0x4c,
	0xf7, 0x49, 0x77, 0x82, 0x35, 0x6b, 0xd6, 0x64, 0x82, 0xf2, 0x66, 0x42,
	0xc9, 0x4f, 0x96, 0x2f, 0x5d, 0xf1, 0xfe, 0x9d, 0x02, 0xae, 0x5d, 0xbb,
	0xb6, 0x8f, 0x80, 0x55, 0x2b, 0x89, 0x98, 0xfe, 0xc7, 0xa7, 0x9f, 0xdd,
	0x7f, 0x3b, 0xed, 0x91, 0xb7, 0x50, 0xc0, 0x08, 0xce, 0x4d, 0xfe, 0x5d,
	0x5b, 0x6e, 0xda, 0x9d, 0x48, 0x51, 0xb1, 0xc2, 0xed, 0xf6, 0x70, 0x46,
	0x95, 0x0d, 0xa1, 0x50, 0xc8, 0x75, 0x27, 0x00, 0x45, 0x27, 0xaf, 0x7b,
	0xbd, 0x99, 0x42, 0x53, 0x1d, 0x7f, 0xdd, 0xb0, 0x61, 0x83, 0x7a, 0x2b,
	0xdd, 0xae, 0x5d, 0x60, 0x9a, 0xaa, 0xbc, 0xd7, 0xf1, 0x5a, 0x17, 0x80,
	0xb5, 0x6b, 0x4b, 0xf3, 0x29, 0x65, 0x4f, 0xce, 0x99, 0x3d, 0x87, 0xe5,
	0x0f, 0x1c, 0xe4, 0x76, 0x79, 0x1c, 0xcf, 0xde, 0x2e, 0xf9, 0x9a, 0x35,
	0xab, 0x8b, 0x28, 0xa1, 0x33, 0x67, 0xcd, 0x9c, 0x4d, 0xf3, 0x72, 0xfb,
	0x07, 0x5b, 0x62, 0x4d, 0x8b, 0x6e, 0xa5, 0xed, 0x97, 0xa2, 0x2b, 0x33,
	0x83, 0xdf, 0xcb, 0xbf, 0x2d, 0x00, 0x61, 0xca, 0xaf, 0x47, 0x8d, 0x1a,
	0xe5, 0xe0, 0x5c, 0x62, 0xec, 0xb8, 0xef, 0x3b, 0x09, 0x25, 0x25, 0xeb,
	0xd6, 0x95, 0x0e, 0xec, 0xfe, 0x8e, 0x76, 0x31, 0xcd, 0xa1, 0x6f, 0x2e,
	0x9e, 0x32, 0xd5, 0x69, 0x59, 0x36, 0xc6, 0x8c, 0x1e, 0xeb, 0x52, 0x14,
	0xb6, 0xa0, 0x3b, 0xed, 0xf1, 0x2d, 0x28, 0xa4, 0x4c, 0x7f, 0x66, 0xf0,
	0x84, 0xce, 0x15, 0xed, 0x02, 0xc0, 0x05, 0x8f, 0x85, 0xc3, 0xe1, 0x24,
	0xa5, 0x14, 0x90, 0x40, 0xd1, 0xc4, 0x22, 0x9d, 0x69, 0x8e, 0x37, 0xbb,
	0x0b, 0x7a, 0xa9, 0xfa, 0xc2, 0x13, 0x7e, 0x7f, 0x76, 0x4e, 0xa6, 0xd7,
	0x47, 0xa4, 0x94, 0x68, 0x88, 0xd4, 0x0b, 0xce, 0x45, 0xf3, 0xcd, 0xba,
	0x3d, 0xeb, 0xa1, 0x13, 0xca, 0xde, 0xbb, 0x7b, 0xd2, 0x42, 0x87, 0xa2,
	0xb8, 0x3b, 0xfd, 0xd7, 0x05, 0x20, 0x95, 0xb0, 0x5f, 0x6b, 0x8e, 0xb6,
	0xd4, 0x44, 0x1a, 0xeb, 0xa5, 0x94, 0x12, 0xb9, 0xfd, 0xf2, 0x98, 0xc2,
	0xd4, 0xc9, 0x2f, 0xad, 0x2b, 0x9d, 0xd6, 0x51, 0xf7, 0xe2, 0x8b, 0x2f,
	0x06, 0x28, 0x21, 0x2f, 0x4d, 0xbe, 0x67, 0x8a, 0x87, 0x73, 0x0e, 0x4a,
	0x09, 0xca, 0x8e, 0x1f, 0x33, 0x2c, 0xc9, 0x1f, 0xbe, 0x39, 0x66, 0x2f,
	0x9f, 0xb2, 0x36, 0xab, 0xdf, 0x84, 0x9c, 0xcc, 0xe0, 0x44, 0x02, 0x88,
	0xdb, 0x03, 0x84, 0x42, 0x21, 0x61, 0x1b, 0xc6, 0x23, 0x87, 0x8f, 0x1c,
	0x4a, 0x32, 0x46, 0x61, 0xdb, 0x36, 0xa6, 0x16, 0x4f, 0x73, 0xe9, 0x8a,
	0xfe, 0xb7, 0x50, 0x28, 0xa4, 0xa4, 0x75, 0x0e, 0x97, 0xfa, 0xea, 0x98,
	0xd1, 0x85, 0x3a, 0x64, 0xdb, 0xef, 0x2f, 0xbe, 0x3c, 0x95, 0x02, 0xb0,
	0x71, 0xc5, 0xd2, 0x15, 0x5f, 0x77, 0x8c, 0x77, 0xec, 0x2d, 0xdc, 0x4b,
	0x35, 0xc7, 0xbc, 0x41, 0x63, 0x17, 0x3a, 0x64, 0xf2, 0x20, 0x8e, 0xef,
	0x9a, 0x7e, 0x7b, 0x00, 0x00, 0x58, 0xbe, 0x7c, 0xd5, 0x09, 0x2e, 0xc4,
	0xbe, 0xf3, 0x55, 0xe7, 0x2d, 0x00, 0x70, 0xb9, 0xdc, 0x08, 0xf6, 0xe9,
	0xd3, 0xdb, 0xe3, 0xd5, 0x17, 0x00, 0xc0, 0xcb, 0x2f, 0xaf, 0x1e, 0x4f,
	0x08, 0x1e, 0x1c, 0x9c, 0x3f, 0x44, 0x13, 0x42, 0x80, 0x73, 0x1b, 0xe7,
	0xab, 0xaa, 0x5a, 0x63, 0xac, 0x75, 0x55, 0xa7, 0xe4, 0x9b, 0x90, 0xc1,
	0x14, 0xb6, 0x6b, 0xd8, 0xa4, 0xc5, 0x4e, 0x2a, 0xaf, 0x40, 0xda, 0x97,
	0x51, 0xf4, 0xf0, 0x47, 0x77, 0x06, 0x00, 0x80, 0xa4, 0x30, 0x16, 0x7c,
	0x76, 0xea, 0xdf, 0x16, 0xa5, 0x04, 0x9c, 0x73, 0x14, 0x4d, 0xbc, 0xd7,
	0x45, 0x08, 0x7d, 0xfe, 0x85, 0x17, 0x5e, 0x08, 0xaa, 0x9a, 0xb6, 0x75,
	0x6a, 0xf1, 0x0c, 0xa7, 0x65, 0x59, 0x50, 0x14, 0x86, 0x23, 0x47, 0x0f,
	0x25, 0x6c, 0xce, 0x4b, 0x42, 0x25, 0xa1, 0x68, 0xa7, 0xe0, 0x3a, 0x7b,
	0x23, 0x38, 0xe8, 0x3e, 0x9f, 0x27, 0x7b, 0x04, 0x44, 0xaa, 0x0c, 0x52,
	0x08, 0x48, 0xc9, 0x7b, 0x06, 0xb0, 0x6a, 0xf1, 0xaa, 0x2b, 0x04, 0xe4,
	0xa5, 0x93, 0x9f, 0x9d, 0x68, 0xa5, 0x94, 0xc0, 0xb6, 0x6d, 0x14, 0x16,
	0x8e, 0xd3, 0x74, 0xa7, 0xba, 0x3b, 0x2b, 0xdb, 0xdf, 0xdf, 0xed, 0xf6,
	0x10, 0x29, 0x25, 0x22, 0x8d, 0x11, 0x11, 0x8b, 0xc5, 0xbe, 0x59, 0xb6,
	0xe4, 0x99, 0xed, 0x1d, 0xc7, 0x97, 0x6d, 0xc6, 0x03, 0x8a, 0xea, 0x7d,
	0x28, 0x77, 0xe4, 0x63, 0x0e, 0x9e, 0xd8, 0x0f, 0xc1, 0x53, 0x10, 0x42,
	0xe0, 0x93, 0x77, 0x67, 0xf5, 0x0c, 0x00, 0x00, 0x34, 0xc5, 0xb1, 0xae,
	0xba, 0xba, 0x3a, 0x66, 0x5a, 0x26, 0xa4, 0x94, 0x18, 0x98, 0x97, 0xaf,
	0x51, 0x4a, 0x26, 0x8c, 0x1c, 0x3e, 0xd2, 0x6d, 0xdb, 0x36, 0x74, 0x5d,
	0xc3, 0xc7, 0x47, 0x0f, 0xa6, 0x6c, 0xd3, 0xfc, 0x3d, 0x21, 0x44, 0xa6,
	0xc7, 0x7d, 0xba, 0x05, 0xd9, 0x84, 0xb2, 0x6d, 0x43, 0x27, 0x2d, 0x74,
	0x4a, 0xab, 0x0a, 0xdc, 0xac, 0x81, 0xe0, 0x02, 0x82, 0x73, 0x4c, 0x98,
	0xb3, 0xb3, 0xe7, 0x00, 0x25, 0x25, 0x25, 0x86, 0x6d, 0xda, 0x4f, 0x1c,
	0x3a, 0x74, 0x20, 0xae, 0xaa, 0x2a, 0x4c, 0xd3, 0xc4, 0xfd, 0xc5, 0xd3,
	0xf0, 0xc5, 0x99, 0x72, 0x00, 0x40, 0x45, 0xe5, 0x59, 0x83, 0x73, 0xb9,
	0x73, 0xd9, 0xb2, 0x95, 0xe5, 0x1d, 0xc7, 0x09, 0xa6, 0x6c, 0xee, 0x3b,
	0x64, 0xba, 0xcb, 0x99, 0x91, 0x0b, 0xbb, 0xf5, 0x04, 0x2c, 0xd3, 0x02,
	0xe7, 0x16, 0x84, 0xe0, 0x90, 0xa2, 0x87, 0x53, 0x90, 0xb6, 0xe5, 0xcb,
	0x57, 0xfc, 0xc3, 0x30, 0x52, 0x5f, 0x36, 0x44, 0xae, 0x0b, 0x21, 0x04,
	0x74, 0x5d, 0x03, 0x63, 0x0a, 0x6a, 0xaf, 0x5d, 0x41, 0x45, 0x65, 0x85,
	0xc1, 0x48, 0x72, 0x71, 0x47, 0x7d, 0xd9, 0x56, 0xfc, 0x46, 0xd5, 0xb3,
	0xa6, 0xe6, 0x14, 0xfc, 0x5c, 0xb3, 0xe2, 0x07, 0x20, 0x6c, 0x03, 0x57,
	0x2f, 0x9e, 0x03, 0x37, 0x2d, 0x08, 0x2e, 0x70, 0x72, 0xf7, 0x2f, 0xbf,
	0x1b, 0x00, 0x00, 0x98, 0x75, 0x75, 0x0b, 0x8e, 0x1e, 0x3e, 0x48, 0x9d,
	0x4e, 0x07, 0x52, 0x86, 0x81, 0xc9, 0x45, 0xf7, 0xa2, 0xfc, 0xd8, 0x61,
	0x69, 0x35, 0x46, 0x4a, 0x17, 0x2d, 0x0a, 0xdd, 0xd8, 0x78, 0x4e, 0x6c,
	0x43, 0x3f, 0x02, 0xfa, 0xe7, 0x82, 0x09, 0x7f, 0x70, 0x72, 0xa3, 0x02,
	0xdc, 0xb8, 0x86, 0x78, 0xb4, 0x19, 0xf5, 0x35, 0x61, 0x48, 0xc1, 0x21,
	0x04, 0xc7, 0xf8, 0x99, 0x9b, 0x3a, 0xc5, 0x56, 0xba, 0x64, 0xeb, 0xc6,
	0x3c, 0xef, 0xee, 0x58, 0xa6, 0x4c, 0x9c, 0x8c, 0x43, 0xbd, 0xb2, 0xe0,
	0xfd, 0xf0, 0x7d, 0xb4, 0x9e, 0x3d, 0x03, 0xe7, 0xb5, 0xab, 0xc4, 0xe5,
	0xeb, 0xf5, 0x14, 0x80, 0x57, 0x00, 0x40, 0x4a, 0x90, 0x13, 0xef, 0x28,
	0x3b, 0xfa, 0x0d, 0xfd, 0x91, 0x43, 0x77, 0x64, 0xc1, 0x68, 0xde, 0x0d,
	0x29, 0x6d, 0x84, 0x2b, 0xcf, 0x26, 0x00, 0xb8, 0x05, 0x17, 0x20, 0xe0,
	0x90, 0xc2, 0xee, 0x39, 0xc0, 0x1e, 0x40, 0xbf, 0xe6, 0x41, 0xbe, 0xbc,
	0x5a, 0x33, 0x6b, 0x4a, 0xe5, 0x39, 0x7c, 0x23, 0x80, 0xea, 0xfd, 0xfb,
	0x30, 0xcc, 0x17, 0x44, 0x9f, 0xdc, 0xa1, 0x38, 0x5d, 0x1f, 0xee, 0xbd,
	0xc1, 0x85, 0x07, 0x9c, 0xad, 0x38, 0x7c, 0x7c, 0x2b, 0x7d, 0xd4, 0xe5,
	0x0d, 0x14, 0x06, 0x06, 0xcc, 0x54, 0x8c, 0xe8, 0xbf, 0x20, 0x85, 0x8d,
	0xba, 0xea, 0x4b, 0x36, 0xb7, 0xad, 0xd3, 0x84, 0x92, 0x71, 0x42, 0x08,
	0x27, 0x21, 0xc0, 0xe7, 0x7b, 0x1e, 0xef, 0x94, 0xa3, 0xcb, 0x14, 0xec,
	0x02, 0x3c, 0xdb, 0x29, 0x5d, 0xbd, 0x93, 0xd2, 0x6a, 0xcb, 0xed, 0xbe,
	0xe2, 0xe3, 0x8e, 0x2f, 0x32, 0x6d, 0xcd, 0x99, 0x6c, 0x8e, 0x22, 0xb1,
	0x77, 0x77, 0x92, 0x12, 0xba, 0xf1, 0x52, 0xa2, 0x31, 0x19, 0x6f, 0x6d,
	0xc5, 0x88, 0xec, 0xbb, 0x9c, 0x4e, 0xa6, 0x7e, 0xd8, 0xd7, 0x9f, 0x5d,
	0x13, 0x59, 0xa2, 0xbd, 0x1e, 0xdb, 0x98, 0xed, 0x8a, 0x9e, 0x2f, 0x03,
	0x37, 0x23, 0x48, 0xc6, 0x63, 0x68, 0xb8, 0x5a, 0x63, 0x9a, 0x92, 0xcf,
	0x05, 0x00, 0x21, 0x38, 0x04, 0x17, 0x18, 0x33, 0xe3, 0xb5, 0x5b, 0x57,
	0x60, 0x3b, 0x70, 0x3f, 0x18, 0xdb, 0x91, 0x17, 0x0c, 0xfa, 0xdc, 0x9a,
	0xa6, 0x9a, 0xb6, 0x0d, 0x4d, 0xd3, 0x00, 0x21, 0x50, 0x71, 0xf9, 0x92,
	0x6c, 0xd5, 0xf9, 0x3b, 0xf3, 0xe2, 0x62, 0xde, 0x26, 0x2f, 0xf1, 0x36,
	0xd8, 0xad, 0x0f, 0x06, 0x4d, 0xaa, 0x0c, 0xf3, 0xe7, 0xd0, 0x2c, 0xb7,
	0xd7, 0xa7, 0x32, 0x86, 0xd4, 0x25, 0x0b, 0x27, 0x7f, 0xfc, 0x01, 0xfa,
	0x3f, 0x1e, 0x84, 0x35, 0xb2, 0x36, 0x21, 0x09, 0x9e, 0xbd, 0x6f, 0x2e,
	0x2e, 0x96, 0x6d, 0x05, 0x84, 0x10, 0x20, 0x00, 0x84, 0xb0, 0xba, 0xaf,
	0xc0, 0x16, 0x60, 0x9a, 0xee, 0x74, 0xbe, 0x5f, 0x90, 0x9b, 0x1b, 0x48,
	0x24, 0x93, 0x66, 0x65, 0x38, 0x5c, 0x73, 0xb1, 0xb6, 0xf6, 0x4f, 0x95,
	0xe1, 0xcb, 0x11, 0x49, 0x08, 0x72, 0x7c, 0xbd, 0xa4, 0x92, 0xc0, 0x69,
	0x00, 0xa8, 0x8e, 0xf2, 0x5f, 0xd5, 0xb6, 0x34, 0x71, 0xa2, 0x50, 0x44,
	0x92, 0x31, 0xb3, 0x6a, 0x40, 0xd8, 0xfe, 0x46, 0x8f, 0xa3, 0x26, 0x5a,
	0x8f, 0xd1, 0x39, 0xf9, 0xa8, 0xdb, 0x14, 0x41, 0xe4, 0x03, 0xa3, 0xe5,
	0xaa, 0x43, 0xac, 0x4f, 0xc7, 0x17, 0x9c, 0x43, 0x70, 0x8e, 0x2f, 0xf7,
	0x3f, 0xdd, 0x15, 0x60, 0x3b, 0xe0, 0xd7, 0x15, 0xe5, 0xef, 0x03, 0x02,
	0x81, 0xcc, 0x9a, 0xfa, 0xfa, 0x96, 0x48, 0x4b, 0xcb, 0xd6, 0x3e, 0x42,
	0x0c, 0xfc, 0x19, 0xe7, 0x25, 0xb6, 0x90, 0xeb, 0x0c, 0xd3, 0x94, 0xba,
	0xc3, 0x41, 0x15, 0x4a, 0x87, 0x00, 0x40, 0x08, 0xb0, 0xbd, 0x52, 0x4f,
	0xd8, 0x90, 0x48, 0x58, 0x31, 0x75, 0xfc, 0xfa, 0xa7, 0x94, 0x71, 0x6f,
	0x17, 0x21, 0xb0, 0xd0, 0x8b, 0x33, 0xd7, 0x2e, 0x60, 0x44, 0x70, 0x20,
	0x5a, 0xff, 0xa9, 0xb9, 0x93, 0x3f, 0xc5, 0x8d, 0xc3, 0x47, 0xdb, 0x1e,
	0x20, 0x30, 0xe2, 0xbe, 0xe7, 0xba, 0x02, 0x50, 0x4a, 0x57, 0xe6, 0xfa,
	0xfd, 0x59, 0x49, 0xc3, 0xe0, 0xf1, 0x54, 0xea, 0xe8, 0x2f, 0x84, 0x98,
	0x5f, 0x0c, 0xd8, 0x00, 0xa0, 0x53, 0xfa, 0x03, 0x4d, 0x51, 0x48, 0xd2,
	0x30, 0x52, 0xdc, 0xb6, 0x3f, 0xef, 0x70, 0x47, 0xf1, 0x60, 0x86, 0x0f,
	0x8c, 0x39, 0x08, 0x6f, 0x49, 0xc0, 0x4c, 0x54, 0xc0, 0x5f, 0x9c, 0x09,
	0x6d, 0xba, 0x69, 0xd6, 0x36, 0x47, 0xec, 0x31, 0x83, 0x87, 0x78, 0x3d,
	0xba, 0xbe, 0x26, 0xad, 0x97, 0xed, 0x3b, 0xe1, 0xcd, 0xab, 0x80, 0x02,
	0x80, 0x24, 0xe4, 0x21, 0x87, 0xa6, 0xd1, 0xeb, 0xcd, 0xcd, 0x11, 0x8b,
	0xf3, 0x1b, 0x27, 0xd6, 0xb7, 0x81, 0xd1, 0x9a, 0xaa, 0x4e, 0xd1, 0x54,
	0x15, 0xd7, 0x1b, 0x1b, 0xe3, 0x75, 0xc0, 0x47, 0x00, 0x18, 0x00, 0xa6,
	0x16, 0xf2, 0x48, 0x4b, 0x6b, 0x1c, 0xb9, 0x19, 0x01, 0x7c, 0xf5, 0xdc,
	0x4e, 0x08, 0xce, 0x11, 0x6d, 0x6a, 0x90, 0xae, 0x62, 0xab, 0xf6, 0xe2,
	0xd5, 0xda, 0x26, 0x8f, 0xae, 0x13, 0x00, 0xf7, 0x00, 0x80, 0x4c, 0x3f,
	0x84, 0x82, 0xa3, 0xe2, 0x68, 0x69, 0x57, 0x00, 0x02, 0xb8, 0x08, 0x00,
	0xcb, 0xb6, 0xd9, 0x5c, 0xa0, 0x16, 0x80, 0x73, 0x1d, 0x30, 0x4d, 0x57,
	0xd5, 0xfd, 0x63, 0x0b, 0x0a, 0xb2, 0xae, 0x47, 0xa3, 0x89, 0x46, 0x29,
	0xb7, 0x2d, 0x06, 0x9c, 0x00, 0x72, 0x4a, 0xe7, 0x63, 0x8e, 0x98, 0x8d,
	0xe1, 0x5f, 0x37, 0xd5, 0x21, 0xe0, 0xce, 0x80, 0x71, 0xc2, 0xc0, 0x57,
	0xaf, 0xd5, 0xe0, 0xc2, 0xd7, 0x61, 0x12, 0x37, 0x45, 0x1e, 0xc9, 0x92,
	0x01, 0x0a, 0x40, 0xef, 0xa5, 0xf4, 0xfe, 0xf8, 0x2f, 0x90, 0x10, 0xd2,
	0x99, 0x7e, 0x17, 0x0c, 0x99, 0xb8, 0xa4, 0x13, 0x40, 0x7a, 0x15, 0xc4,
	0x02, 0x3e, 0x5f, 0x56, 0x34, 0x99, 0x54, 0xb7, 0x37, 0x35, 0x1d, 0x00,
	0x21, 0x19, 0x01, 0x8f, 0x27, 0x7f, 0x58, 0xff, 0xfe, 0x19, 0x97, 0x1a,
	0x1a, 0x52, 0x35, 0x8d, 0x8d, 0x15, 0x8b, 0x6d, 0x7b, 0x33, 0x80, 0xde,
	0x03, 0x73, 0x90, 0xd1, 0x3b, 0x9b, 0x6e, 0x60, 0x39, 0xf7, 0xe8, 0xfa,
	0x7c, 0xa0, 0xfc, 0x8d, 0x53, 0x18, 0xdb, 0x77, 0x10, 0xaa, 0xcb, 0x1a,
	0x70, 0xe5, 0x80, 0x03, 0x8e, 0x7c, 0x07, 0x02, 0x9a, 0x0e, 0x55, 0x55,
	0xc1, 0x21, 0x11, 0xbc, 0x7b, 0x08, 0x54, 0x06, 0x48, 0x22, 0x21, 0x85,
	0x84, 0xe0, 0x9d, 0x57, 0x01, 0x01, 0x80, 0x1d, 0x8c, 0x3d, 0xe6, 0xcf,
	0xcc, 0x7c, 0x75, 0x78, 0x6e, 0x6e, 0x86, 0x68, 0xbf, 0x98, 0xb2, 0x2c,
	0x59, 0x5e, 0x55, 0x15, 0x6d, 0x16, 0x62, 0xdf, 0x52, 0xcb, 0x2a, 0x6d,
	0x6a, 0xab, 0x96, 0xf2, 0xca, 0x12, 0xb2, 0xba, 0xef, 0x5d, 0xfd, 0xa6,
	0xf6, 0xce, 0x9b, 0xa6, 0x99, 0xb1, 0x4f, 0xc0, 0x2b, 0x5b, 0x60, 0x6c,
	0x6a, 0xc2, 0x50, 0x7f, 0x2e, 0x02, 0x9e, 0x4c, 0x48, 0x29, 0xa1, 0xab,
	0x2a, 0x2e, 0x34, 0xd5, 0x21, 0x36, 0x21, 0x8e, 0xbe, 0xbf, 0xf5, 0x82,
	0x31, 0x40, 0x4a, 0x00, 0x52, 0xe2, 0x5a, 0xf8, 0x02, 0x00, 0x20, 0xfd,
	0x5d, 0x70, 0xe3, 0xc3, 0x64, 0x07, 0xa5, 0x0b, 0x18, 0x63, 0x4b, 0x28,
	0x63, 0x4c, 0x08, 0x41, 0x84, 0x10, 0xe5, 0x95, 0xb6, 0xfd, 0x7c, 0x08,
	0xa8, 0x6a, 0xaf, 0x14, 0x7d, 0x65, 0x09, 0x66, 0x14, 0xe4, 0xa9, 0x6f,
	0xe6, 0x8d, 0x7a, 0xd4, 0x61, 0x25, 0xbf, 0x85, 0x9d, 0x0a, 0x83, 0x10,
	0x09, 0x18, 0x1c, 0xb1, 0xf7, 0x62, 0x48, 0x7e, 0x9a, 0x02, 0x03, 0x83,
	0x6d, 0xdb, 0xe8, 0x75, 0xbf, 0x0b, 0x39, 0x8f, 0x78, 0x01, 0x22, 0xdb,
	0x1e, 0x02, 0x48, 0x48, 0x29, 0xe1, 0xf6, 0x4f, 0xc7, 0xc5, 0xf2, 0x8d,
	0x5d, 0x01, 0xee, 0x64, 0x87, 0xb6, 0xc3, 0xaf, 0x59, 0xe4, 0xdb, 0xbe,
	0x05, 0x3f, 0xf4, 0xb9, 0xb3, 0x0a, 0x01, 0x69, 0x00, 0x84, 0x41, 0x4a,
	0x09, 0x48, 0x01, 0x09, 0x09, 0x08, 0xde, 0xd6, 0x4a, 0x01, 0x29, 0x05,
	0x00, 0x01, 0x48, 0x09, 0x29, 0xdb, 0x4f, 0x42, 0xed, 0xfd, 0xcb, 0x67,
	0xb6, 0xde, 0x00, 0xe8, 0xd1, 0xcb, 0x08, 0x00, 0x54, 0x03, 0x9b, 0x25,
	0x91, 0xbe, 0x2b, 0xe7, 0xf6, 0x02, 0xd8, 0xdb, 0xd3, 0x61, 0xb7, 0x0d,
	0x09, 0xc0, 0xea, 0x71, 0x05, 0xd0, 0x06, 0xab, 0x01, 0xd0, 0xdb, 0x5b,
	0xb5, 0x43, 0x9b, 0x76, 0x86, 0xff, 0xee, 0xae, 0x1c, 0x6d, 0x7b, 0x89,
	0xd5, 0xc1, 0xcd, 0x76, 0x4f, 0xb6, 0xb7, 0xf6, 0x77, 0x01, 0xb8, 0xd9,
	0x48, 0x7b, 0x32, 0xda, 0xde, 0x4f, 0x7b, 0xda, 0x64, 0x07, 0x6f, 0x9f,
	0x0f, 0x48, 0xfc, 0xbf, 0xd9, 0x7f, 0x00, 0x76, 0x69, 0xe5, 0x89, 0x4b,
	0x1e, 0x7c, 0x1b, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae,
	0x42, 0x60, 0x82,
}

var __32x32_places_folder_png = []byte{
	0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
	0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x20,
	0x08, 0x06, 0x00, 0x00, 0x00, 0x73, 0x7a, 0x7a, 0xf4, 0x00, 0x00, 0x00,
	0x04, 0x73, 0x42, 0x49, 0x54, 0x08, 0x08, 0x08, 0x08, 0x7c, 0x08, 0x64,
	0x88, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00, 0x0d,
	0xd7, 0x00, 0x00, 0x0d, 0xd7, 0x01, 0x42, 0x28, 0x9b, 0x78, 0x00, 0x00,
	0x00, 0x19, 0x74, 0x45, 0x58, 0x74, 0x53, 0x6f, 0x66, 0x74, 0x77, 0x61,
	0x72, 0x65, 0x00, 0x77, 0x77, 0x77, 0x2e, 0x69, 0x6e, 0x6b, 0x73, 0x63,
	0x61, 0x70, 0x65, 0x2e, 0x6f, 0x72, 0x67, 0x9b, 0xee, 0x3c, 0x1a, 0x00,
	0x00, 0x04, 0x15, 0x49, 0x44, 0x41, 0x54, 0x58, 0x85, 0xed, 0x97, 0x3d,
	0x6f, 0x1c, 0x45, 0x18, 0xc7, 0x7f, 0x33, 0xbb, 0x77, 0x7b, 0xaf, 0xf6,
	0x39, 0x91, 0x30, 0x09, 0x05, 0x56, 0x94, 0xc2, 0x1f, 0x00, 0x09, 0x05,
	0x21, 0x53, 0x6e, 0x95, 0x82, 0x1a, 0x89, 0x02, 0x5a, 0x3a, 0x3e, 0x40,
	0x24, 0x3e, 0x40, 0x4a, 0x84, 0x44, 0x85, 0x68, 0xa1, 0x43, 0x48, 0xa7,
	0x40, 0x17, 0xc9, 0x8a, 0x02, 0x8a, 0xd2, 0x45, 0xc2, 0xc6, 0xc4, 0x28,
	0x16, 0xc6, 0xf7, 0xba, 0x77, 0xde, 0x97, 0x99, 0x9d, 0x19, 0x8a, 0x7b,
	0xc9, 0x3a, 0x77, 0x8e, 0x13, 0x72, 0x52, 0x28, 0xf8, 0x4b, 0x8f, 0x76,
	0x76, 0x76, 0xf7, 0x79, 0x7e, 0xf3, 0x3c, 0x33, 0xb3, 0xbb, 0x22, 0x0c,
	0x43, 0x5e, 0xa7, 0xe4, 0x6b, 0x8d, 0xfe, 0x5f, 0x00, 0xf0, 0x01, 0x6e,
	0xdc, 0xb8, 0xe1, 0x2b, 0xa5, 0x7e, 0x36, 0xc6, 0xbc, 0x77, 0xd1, 0x03,
	0x42, 0x88, 0xdc, 0x5a, 0xfb, 0xf9, 0xc3, 0x87, 0x0f, 0xbf, 0x5c, 0x19,
	0x40, 0x9a, 0xa6, 0x5b, 0x95, 0x4a, 0xe5, 0x9d, 0x9b, 0x37, 0x6f, 0xfa,
	0x49, 0x92, 0xe0, 0x9c, 0x03, 0xc0, 0x5a, 0x0b, 0x30, 0x3f, 0x9f, 0xb6,
	0xfd, 0x3b, 0x77, 0xee, 0xdc, 0xde, 0xde, 0xde, 0xfe, 0xfe, 0xd1, 0xa3,
	0x47, 0xc7, 0x2b, 0x01, 0x50, 0x4a, 0x65, 0xd5, 0x6a, 0xd5, 0x1d, 0x1d,
	0x1d, 0xd1, 0xe9, 0x74, 0x70, 0xce, 0x2d, 0x35, 0x00, 0x21, 0x04, 0x9b,
	0x9b, 0x9b, 0xf9, 0xc1, 0xc1, 0xc1, 0x47, 0xc0, 0xed, 0x95, 0x00, 0x68,
	0xad, 0xd3, 0x2c, 0xcb, 0xc4, 0xa5, 0x4b, 0x1b, 0x18, 0x63, 0xb0, 0xd6,
	0x9e, 0x09, 0x5c, 0xcc, 0x84, 0x10, 0x82, 0x6a, 0xb5, 0x5a, 0x3f, 0x3c,
	0x3c, 0xfc, 0x62, 0x7b, 0x7b, 0xfb, 0xd6, 0xac, 0x7f, 0x99, 0x9c, 0x73,
	0xda, 0x5a, 0xfb, 0xf1, 0xde, 0xde, 0xde, 0x8f, 0xcf, 0x05, 0x00, 0xb2,
	0x2c, 0xcb, 0xbc, 0x4e, 0xa7, 0x4b, 0xa7, 0xd3, 0x99, 0x03, 0xcc, 0x8e,
	0xb3, 0x20, 0xc5, 0x40, 0x5b, 0x5b, 0x5b, 0xf5, 0x46, 0xa3, 0x41, 0xb3,
	0xd9, 0x44, 0x08, 0x81, 0x10, 0x02, 0x00, 0x29, 0xe5, 0xbc, 0x1d, 0x45,
	0x11, 0xf7, 0xee, 0xdd, 0xbb, 0x05, 0x3c, 0x1f, 0xe0, 0xf2, 0xe5, 0xcb,
	0x69, 0xbf, 0xdf, 0xf7, 0x36, 0x36, 0x5a, 0x68, 0xad, 0x17, 0x00, 0x96,
	0x95, 0x62, 0xa6, 0x38, 0x8e, 0x01, 0xe6, 0x10, 0x45, 0x8b, 0xe3, 0x18,
	0x63, 0x4c, 0xed, 0xbc, 0xe0, 0x73, 0x80, 0xdd, 0xdd, 0x5d, 0x75, 0xed,
	0xda, 0x35, 0xd9, 0xeb, 0xf5, 0xe6, 0x19, 0x00, 0x96, 0x82, 0xcc, 0xb2,
	0x51, 0xd4, 0x6c, 0xc4, 0xc5, 0xe0, 0x52, 0xca, 0x19, 0x40, 0xe5, 0x42,
	0x00, 0x00, 0x63, 0x8c, 0x6d, 0x36, 0xd7, 0x64, 0x9a, 0x66, 0xdc, 0x3f,
	0xb4, 0xdc, 0xdd, 0x3f, 0x1b, 0xe4, 0xbc, 0x3a, 0x3f, 0xab, 0x19, 0xcc,
	0xe4, 0x99, 0x16, 0xce, 0x5d, 0xb9, 0xce, 0xdb, 0x1f, 0xe8, 0xe2, 0x3d,
	0x9e, 0x27, 0xbe, 0x5d, 0xff, 0xfd, 0x9b, 0x4f, 0xce, 0x00, 0x38, 0xe7,
	0x74, 0xb7, 0xdb, 0xf5, 0xbb, 0xdd, 0x2e, 0x8f, 0x3b, 0x0d, 0x3e, 0xfd,
	0xf0, 0x5d, 0xae, 0xbf, 0xb5, 0x51, 0x70, 0x36, 0x3d, 0x3e, 0x2f, 0xfa,
	0x12, 0xc8, 0x69, 0xcf, 0x3c, 0xce, 0x93, 0xce, 0x98, 0xaf, 0xbe, 0xbb,
	0xff, 0xfe, 0xec, 0xbc, 0x98, 0x01, 0xdd, 0x68, 0xd4, 0xab, 0x5a, 0x6b,
	0xd4, 0x1f, 0x92, 0x66, 0xb5, 0xcc, 0xfe, 0xdf, 0x63, 0xa2, 0x38, 0x9f,
	0x8c, 0x6c, 0xe9, 0x68, 0xcf, 0x23, 0x11, 0x0b, 0x4d, 0x01, 0x34, 0x2a,
	0x3e, 0x2a, 0xd3, 0x08, 0x41, 0x67, 0x76, 0x79, 0xbe, 0x15, 0x1b, 0x63,
	0x74, 0xbf, 0x3f, 0xa0, 0xdb, 0xed, 0x12, 0x67, 0x96, 0x7a, 0xb5, 0x84,
	0x35, 0x93, 0x1b, 0xe4, 0xd4, 0xc1, 0xb3, 0x86, 0x3b, 0xcf, 0xdc, 0x53,
	0xb3, 0x13, 0xb3, 0xd6, 0x91, 0x64, 0x86, 0x34, 0xcb, 0xc1, 0x89, 0xf9,
	0x06, 0x56, 0x2c, 0x41, 0x56, 0xa9, 0x04, 0xb4, 0x5a, 0x2d, 0x32, 0x23,
	0xa8, 0x05, 0x25, 0xac, 0x53, 0x78, 0x72, 0x35, 0xaf, 0x8b, 0x71, 0x9a,
	0x53, 0x6f, 0xfa, 0x8c, 0x86, 0x39, 0xd6, 0xba, 0x27, 0x0b, 0x00, 0x79,
	0x9e, 0xab, 0x28, 0x1a, 0xd1, 0xef, 0x0f, 0xd0, 0xe6, 0x0d, 0xaa, 0x81,
	0x8f, 0x73, 0x0e, 0x4f, 0x9e, 0x9b, 0xe7, 0x17, 0x93, 0x83, 0x51, 0xaa,
	0xd1, 0xb9, 0x25, 0xf0, 0x25, 0x71, 0xaa, 0xad, 0x31, 0xf9, 0xd1, 0x02,
	0x80, 0x31, 0x26, 0x2b, 0x97, 0x4b, 0x54, 0x9b, 0x1b, 0xac, 0xd5, 0xca,
	0x38, 0x40, 0x0a, 0xb1, 0xbc, 0xf8, 0x2f, 0x28, 0xe3, 0x1c, 0xa3, 0x54,
	0x93, 0x5b, 0x87, 0xe7, 0x09, 0x82, 0xb2, 0xc7, 0x69, 0x92, 0x29, 0x21,
	0xc4, 0xc9, 0x02, 0x80, 0xb5, 0x36, 0x1b, 0x8d, 0xc6, 0x1c, 0x0f, 0x14,
	0xeb, 0xf5, 0x4b, 0xe8, 0xdc, 0xbe, 0xd2, 0xe8, 0x33, 0x6d, 0x89, 0x33,
	0x03, 0x4e, 0xe0, 0x4f, 0xfd, 0x94, 0x3d, 0xc9, 0xe8, 0x54, 0xe5, 0x82,
	0xa7, 0x93, 0xb0, 0x98, 0x81, 0xd4, 0xf7, 0x7d, 0xbc, 0x20, 0xa0, 0x49,
	0x99, 0x4c, 0xd9, 0x0b, 0x83, 0x4c, 0xe6, 0x98, 0xc3, 0xba, 0xc9, 0x3e,
	0x61, 0xec, 0xc4, 0x54, 0x6e, 0x97, 0xad, 0x48, 0x9c, 0x83, 0xc1, 0x28,
	0xb5, 0xb9, 0x73, 0x8b, 0x00, 0xd6, 0xda, 0x64, 0x3c, 0x1e, 0xd3, 0x19,
	0xf8, 0x54, 0x5a, 0x65, 0xa2, 0x44, 0x93, 0xe9, 0xe9, 0x4b, 0x08, 0xc8,
	0x8d, 0x45, 0x1b, 0x87, 0xce, 0x2d, 0xb9, 0x99, 0x6e, 0xcb, 0x2f, 0x99,
	0x95, 0x44, 0x19, 0x86, 0xe3, 0xc4, 0x13, 0xd2, 0x5b, 0x5a, 0x82, 0x54,
	0x08, 0x81, 0x0c, 0x1a, 0x94, 0x4a, 0x3e, 0xa3, 0x44, 0x13, 0x25, 0x9a,
	0x54, 0x19, 0x94, 0xb6, 0x2f, 0x1d, 0x6c, 0x99, 0xe2, 0x2c, 0xe7, 0x34,
	0xd1, 0x3e, 0xe7, 0x94, 0x20, 0x8e, 0xe3, 0x53, 0x7a, 0x51, 0x85, 0x4a,
	0x0d, 0x1e, 0x9f, 0xc4, 0x0c, 0x63, 0xbd, 0xd4, 0xd1, 0xbf, 0x91, 0x00,
	0x86, 0xb1, 0x42, 0x19, 0x53, 0xfa, 0xf5, 0xea, 0x5e, 0x2f, 0x7c, 0xfc,
	0x0c, 0x80, 0xb5, 0x36, 0x06, 0x81, 0xf5, 0x6b, 0x64, 0xb9, 0x25, 0x8a,
	0x35, 0x4a, 0x5f, 0x3c, 0x0f, 0x5e, 0x54, 0x52, 0x0a, 0x4e, 0x86, 0x09,
	0x52, 0xc8, 0x38, 0xdc, 0xdd, 0x9d, 0x3b, 0x3e, 0x33, 0x07, 0x92, 0x24,
	0x21, 0x4a, 0x0c, 0x57, 0xaf, 0x04, 0x54, 0x03, 0x8f, 0xa0, 0xbc, 0xba,
	0x6f, 0x56, 0x29, 0x04, 0x69, 0xaa, 0x90, 0x52, 0x0c, 0x8b, 0xfd, 0xc5,
	0x12, 0x24, 0x00, 0x9a, 0x12, 0xeb, 0x55, 0x8f, 0x7a, 0x69, 0x15, 0x55,
	0x7f, 0x2a, 0xe7, 0x1c, 0xfd, 0x24, 0x41, 0x58, 0x3b, 0x58, 0x00, 0x68,
	0xb7, 0xdb, 0x62, 0x67, 0x67, 0xc7, 0x44, 0xb1, 0x62, 0x70, 0xea, 0xf8,
	0xf3, 0x64, 0x88, 0xec, 0xbe, 0xe2, 0x0e, 0xb8, 0x44, 0xc7, 0xc7, 0x43,
	0x9b, 0x24, 0xc3, 0x07, 0xbb, 0xed, 0x76, 0x2d, 0x0c, 0xc3, 0x78, 0x0e,
	0x00, 0x78, 0x51, 0x14, 0xfd, 0xf4, 0xcb, 0xa1, 0xf8, 0x4c, 0xad, 0xe3,
	0xff, 0xb6, 0xff, 0xca, 0x1f, 0xbb, 0x67, 0xe4, 0xc0, 0x02, 0x58, 0x9d,
	0x1e, 0x1c, 0x3f, 0xf8, 0xe1, 0xeb, 0xe2, 0x35, 0x31, 0xfb, 0x35, 0x6b,
	0xb7, 0xdb, 0xcd, 0x60, 0x6d, 0xed, 0xcd, 0x5a, 0xd0, 0xda, 0x74, 0x38,
	0x29, 0x85, 0x5c, 0xc9, 0x12, 0xc8, 0x8d, 0x31, 0x2a, 0x4b, 0x6b, 0xb9,
	0x10, 0x79, 0x3e, 0x3a, 0xe9, 0x01, 0x7f, 0x85, 0x61, 0xd8, 0x5b, 0x00,
	0x98, 0x42, 0x48, 0x20, 0x60, 0x92, 0x99, 0x7c, 0x15, 0x00, 0x53, 0x05,
	0x40, 0x0a, 0xa8, 0x30, 0x0c, 0xcf, 0x2c, 0x2d, 0xf1, 0xff, 0xcf, 0xe9,
	0xeb, 0x06, 0xf8, 0x07, 0xbc, 0x32, 0xa5, 0x97, 0xcb, 0x08, 0x37, 0x2b,
	0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
}

var __32x32_mimetypes_x_office_spreadsheet_png = []byte{
	0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
	0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x20,
	0x08, 0x06, 0x00, 0x00, 0x00, 0x73, 0x7a, 0x7a, 0xf4, 0x00, 0x00, 0x00,
	0x04, 0x73, 0x42, 0x49, 0x54, 0x08, 0x08, 0x08, 0x08, 0x7c, 0x08, 0x64,
	0x88, 0x00, 0x00, 0x05, 0xa5, 0x49, 0x44, 0x41, 0x54, 0x58, 0x85, 0xe5,
	0x97, 0xcd, 0x6b, 0x54, 0x57, 0x18, 0xc6, 0x7f, 0xe7, 0xde, 0x3b, 0x93,
	0x51, 0x67, 0x92, 0x8c, 0x66, 0x32, 0x6a, 0x26, 0x4d, 0x94, 0x18, 0x27,
	0xa9, 0x50, 0xbf, 0x5a, 0x2d, 0x94, 0x76, 0xd1, 0x85, 0x05, 0x41, 0x8b,
	0x60, 0x75, 0x53, 0x70, 0x21, 0x0a, 0x55, 0xba, 0x71, 0x51, 0xa8, 0xb4,
	0x7f, 0x40, 0xd7, 0xd5, 0x45, 0xa5, 0x90, 0x6e, 0x5a, 0xa8, 0x20, 0x34,
	0x15, 0x0a, 0x6d, 0xa1, 0x25, 0x58, 0x2c, 0xa4, 0xd6, 0x42, 0x4d, 0xa2,
	0xf9, 0x20, 0xc9, 0xc4, 0x64, 0x3e, 0x4c, 0xa2, 0x13, 0x93, 0xcc, 0xdc,
	0xef, 0x2e, 0x32, 0xf7, 0xf4, 0xde, 0xc9, 0x97, 0x59, 0x74, 0xd5, 0x03,
	0x87, 0x7b, 0xde, 0xf3, 0x9e, 0x73, 0xde, 0xe7, 0x3c, 0xef, 0xf3, 0xde,
	0xb9, 0x03, 0xff, 0xf7, 0x26, 0xaa, 0x27, 0xae, 0x5d, 0xbb, 0x76, 0x4a,
	0xd3, 0xb4, 0x2e, 0x20, 0xa6, 0xaa, 0x2a, 0x8a, 0xa2, 0xe0, 0x38, 0x0e,
	0xb6, 0x6d, 0xcb, 0x6e, 0x59, 0x96, 0x7c, 0xfa, 0xc7, 0x6b, 0xcd, 0x01,
	0xcf, 0x2d, 0xcb, 0x3a, 0xd7, 0xd5, 0xd5, 0x75, 0xcb, 0x1f, 0x4f, 0x5b,
	0x86, 0x48, 0x88, 0x2f, 0xcf, 0x9f, 0x3f, 0x1f, 0xab, 0x8c, 0xe5, 0xbc,
	0xeb, 0xba, 0x81, 0x75, 0x7e, 0xfb, 0x05, 0xc7, 0xb1, 0x4b, 0x97, 0x2e,
	0x7d, 0x09, 0xac, 0x0d, 0xc0, 0xb6, 0xed, 0x7a, 0x80, 0xd1, 0xd1, 0x51,
	0x84, 0x10, 0x12, 0x84, 0xff, 0xe9, 0x07, 0xe6, 0x1f, 0xaf, 0x64, 0x7b,
	0x40, 0x1a, 0x1b, 0x1b, 0x31, 0x0c, 0xa3, 0xbe, 0xda, 0xb7, 0x0c, 0x80,
	0xeb, 0xba, 0x32, 0xc8, 0x8d, 0x1b, 0x37, 0x48, 0x24, 0x12, 0x81, 0xa0,
	0xf9, 0x7c, 0x9e, 0x64, 0x32, 0x29, 0xed, 0x42, 0xa1, 0x40, 0x32, 0x99,
	0x94, 0xfb, 0x0b, 0x85, 0x02, 0x8d, 0x8d, 0x8d, 0xd2, 0x9e, 0x9e, 0x9e,
	0xe6, 0xc2, 0x85, 0x0b, 0xcb, 0x40, 0xad, 0x0a, 0xc0, 0x71, 0x1c, 0x79,
	0x93, 0x54, 0x2a, 0x45, 0x2a, 0x95, 0x0a, 0xdc, 0xaa, 0xa6, 0xa6, 0x26,
	0x30, 0x17, 0x89, 0x44, 0x48, 0xa5, 0x52, 0x72, 0x8f, 0xdf, 0xf6, 0xfc,
	0xde, 0xda, 0xea, 0x34, 0xae, 0x0a, 0xc0, 0x63, 0xc1, 0x3b, 0xb4, 0xfa,
	0x59, 0x9d, 0x9a, 0x95, 0x68, 0xf7, 0xb7, 0xb5, 0xfc, 0x2b, 0x69, 0x40,
	0x8e, 0xa7, 0xa6, 0xa6, 0xb0, 0x6d, 0x3b, 0x10, 0xac, 0x50, 0x28, 0x04,
	0xd6, 0xe4, 0xf3, 0x79, 0x4c, 0xd3, 0x94, 0xfe, 0x7c, 0x3e, 0xef, 0xa9,
	0x5e, 0xfa, 0x37, 0xcc, 0x80, 0x77, 0xd8, 0xce, 0x9d, 0x3b, 0x03, 0xf4,
	0x0a, 0x21, 0xd0, 0x34, 0x8d, 0xe3, 0xc7, 0x8f, 0xcb, 0x43, 0x47, 0x46,
	0x46, 0x68, 0x6b, 0x6b, 0x93, 0x6b, 0x86, 0x87, 0x87, 0xa5, 0x0d, 0x30,
	0x3c, 0x3c, 0x8c, 0xa2, 0x28, 0x2f, 0x0e, 0xc0, 0xbb, 0x9d, 0x10, 0x82,
	0x6c, 0x36, 0x8b, 0xe3, 0x38, 0xcb, 0x44, 0x38, 0x34, 0x34, 0x24, 0xd7,
	0x4f, 0x4c, 0x4c, 0x04, 0x40, 0x67, 0x32, 0x19, 0x69, 0x03, 0x64, 0x32,
	0x19, 0xd2, 0xe9, 0xf4, 0xc6, 0x01, 0x00, 0xec, 0xd8, 0xb1, 0x83, 0xe6,
	0xe6, 0xe6, 0x00, 0x00, 0x55, 0x55, 0xd9, 0xbb, 0x77, 0xaf, 0xb4, 0x43,
	0xa1, 0x50, 0x80, 0x01, 0x4d, 0xd3, 0x02, 0x0c, 0x68, 0x9a, 0xb6, 0xb1,
	0x14, 0xd8, 0xb6, 0x2d, 0x45, 0x98, 0xcb, 0xe5, 0x96, 0x6d, 0x28, 0x14,
	0x0a, 0x0c, 0x0e, 0x0e, 0xca, 0x80, 0xff, 0x19, 0x03, 0x9e, 0x06, 0x9a,
	0x9b, 0x9b, 0xa5, 0x4f, 0x08, 0x41, 0x28, 0x14, 0x92, 0x07, 0x7a, 0xb6,
	0x9f, 0x01, 0x55, 0x55, 0xd9, 0xb3, 0x67, 0x8f, 0xdc, 0xa3, 0xaa, 0xaa,
	0x64, 0xc0, 0x0f, 0x6c, 0x5d, 0x00, 0x80, 0xd4, 0x80, 0x77, 0xb8, 0xa7,
	0xf2, 0x47, 0x8f, 0x1e, 0x49, 0x3b, 0x93, 0xc9, 0x04, 0x40, 0xaf, 0xc4,
	0x40, 0x47, 0x47, 0xc7, 0xc6, 0x18, 0xf0, 0x52, 0xe0, 0x55, 0x81, 0xbf,
	0xf6, 0x55, 0x55, 0x25, 0x9d, 0x4e, 0x07, 0xec, 0xf6, 0xf6, 0x76, 0x09,
	0x40, 0xd3, 0xb4, 0x00, 0x03, 0x7e, 0x0d, 0xbc, 0x10, 0x03, 0xfe, 0x1a,
	0xf6, 0xbf, 0x07, 0xbc, 0x9e, 0xcb, 0xe5, 0x02, 0x1a, 0x18, 0x1f, 0x1b,
	0x23, 0x7b, 0xef, 0x1e, 0xf9, 0xfb, 0xf7, 0x79, 0x36, 0x32, 0xc2, 0x7c,
	0x2e, 0x47, 0x44, 0x51, 0x70, 0x34, 0x8d, 0xf0, 0xd6, 0xad, 0x28, 0x89,
	0x04, 0xe1, 0x73, 0xe7, 0xe8, 0x7c, 0xfb, 0xed, 0x8d, 0xa5, 0xc0, 0xaf,
	0x81, 0xea, 0x2a, 0x48, 0xa7, 0xd3, 0xd8, 0xa6, 0x49, 0xef, 0x57, 0x5f,
	0x31, 0x70, 0xfd, 0x3a, 0xfb, 0x1a, 0x1a, 0x78, 0x6b, 0xd7, 0x2e, 0x5a,
	0x3a, 0x3b, 0x89, 0x1d, 0x3a, 0x84, 0xeb, 0x38, 0x38, 0xa6, 0x49, 0x71,
	0x6e, 0x8e, 0xb1, 0x5c, 0x8e, 0xbe, 0x2b, 0x57, 0xe8, 0x2e, 0x97, 0x89,
	0xd4, 0xd5, 0x71, 0x1a, 0xc2, 0x37, 0xc1, 0x58, 0x17, 0x80, 0xc7, 0xc0,
	0x4a, 0xef, 0x81, 0x3f, 0x7b, 0x7a, 0xb8, 0xf3, 0xc9, 0x27, 0x1c, 0x88,
	0x46, 0xb9, 0x7a, 0xf2, 0x24, 0x9b, 0xc3, 0x61, 0x60, 0x29, 0xc7, 0xb6,
	0x61, 0xe0, 0x98, 0x26, 0x8e, 0x69, 0x12, 0x11, 0x82, 0xf6, 0x86, 0x06,
	0xda, 0xea, 0xea, 0x58, 0x58, 0x5c, 0xe4, 0xa7, 0x81, 0x01, 0xee, 0xc2,
	0x6f, 0x1f, 0xc0, 0xa9, 0xeb, 0x30, 0xb1, 0x2a, 0x00, 0x4f, 0x03, 0x4d,
	0x4d, 0x4d, 0x92, 0x01, 0x8f, 0x15, 0x61, 0x9a, 0xdc, 0xbd, 0x7a, 0x95,
	0x77, 0x3b, 0x3b, 0x39, 0xdc, 0xd6, 0x06, 0x95, 0x94, 0x39, 0xa6, 0x89,
	0x6d, 0x59, 0x32, 0xb8, 0x63, 0x9a, 0xd8, 0xbe, 0x71, 0xc8, 0xb2, 0x78,
	0xa7, 0xb5, 0x95, 0x44, 0x28, 0x74, 0xf8, 0xbb, 0xe1, 0xe1, 0x1f, 0x2f,
	0xc0, 0xd1, 0x2f, 0xa0, 0xb8, 0xae, 0x06, 0x3c, 0x06, 0x3c, 0x00, 0x43,
	0x37, 0x6f, 0x72, 0x28, 0x1e, 0xe7, 0x70, 0x47, 0x07, 0xe8, 0x3a, 0x8e,
	0x6d, 0xaf, 0x18, 0x30, 0x30, 0xe7, 0x03, 0xb6, 0x2f, 0x1e, 0x67, 0x68,
	0xdb, 0xb6, 0x74, 0xff, 0xcc, 0xcc, 0x47, 0xc0, 0xc7, 0x6b, 0xa6, 0xa0,
	0x5a, 0x03, 0x42, 0x08, 0xfa, 0x1f, 0x3e, 0xe4, 0xf5, 0xb3, 0x67, 0x71,
	0x2d, 0x0b, 0xbb, 0x54, 0x5a, 0x37, 0xe0, 0x32, 0x50, 0xae, 0xcb, 0x81,
	0x44, 0x82, 0xbe, 0x99, 0x99, 0xb3, 0xab, 0x02, 0xf0, 0xea, 0x75, 0x6a,
	0x6a, 0x4a, 0x8e, 0x3d, 0x16, 0xf4, 0xe9, 0x69, 0x6a, 0x6b, 0x6b, 0xb1,
	0x9e, 0x3e, 0xc5, 0x29, 0x95, 0xfe, 0x0d, 0x50, 0x09, 0x6a, 0x9b, 0x26,
	0xe3, 0x6f, 0xec, 0xe7, 0xdb, 0xf2, 0x6b, 0xe0, 0xba, 0x98, 0x86, 0x81,
	0x6e, 0x18, 0x58, 0x86, 0x81, 0x6e, 0x98, 0x38, 0xb6, 0x49, 0xab, 0x53,
	0x44, 0x3c, 0xfc, 0xf4, 0x25, 0x40, 0x59, 0x93, 0x01, 0x4f, 0x03, 0x32,
	0xff, 0x42, 0x70, 0xdf, 0x75, 0x79, 0x92, 0xcd, 0xb2, 0x79, 0xcb, 0x16,
	0xec, 0x72, 0x79, 0xd9, 0x0d, 0x6d, 0xd7, 0xa6, 0xfc, 0x7e, 0x03, 0xdb,
	0xba, 0x8b, 0xfc, 0xb9, 0x98, 0x46, 0xd7, 0x0d, 0x0c, 0x43, 0x47, 0xd7,
	0x0d, 0x74, 0xdd, 0x20, 0xa2, 0xb9, 0x44, 0x67, 0x17, 0x01, 0x54, 0x20,
	0xba, 0xaa, 0x06, 0x84, 0x10, 0x4c, 0x4e, 0x4e, 0x06, 0xde, 0x84, 0x00,
	0x4a, 0x2c, 0x46, 0x6f, 0x4f, 0x0f, 0xc9, 0x33, 0x67, 0x50, 0x66, 0x66,
	0xb0, 0xab, 0x58, 0x28, 0xbe, 0x12, 0x27, 0x17, 0xce, 0xb2, 0x6b, 0xff,
	0xdf, 0xf4, 0xf6, 0xec, 0xc2, 0xb2, 0xec, 0x4a, 0xb7, 0x08, 0x6b, 0xd0,
	0x1e, 0xd1, 0xc9, 0x67, 0xc6, 0x88, 0x43, 0x1e, 0x88, 0x28, 0x6b, 0xa5,
	0xa0, 0xa9, 0xa9, 0x89, 0x96, 0x96, 0x16, 0xd9, 0x5b, 0x5b, 0x5b, 0xa9,
	0xdd, 0xb7, 0x8f, 0x81, 0xc9, 0x49, 0xfe, 0xf8, 0xe1, 0x07, 0x4a, 0xc9,
	0x24, 0x6e, 0x32, 0xb9, 0xf4, 0xe9, 0x5d, 0x2e, 0x63, 0x95, 0x4a, 0x64,
	0x0e, 0x0b, 0xa6, 0xf5, 0x31, 0x1e, 0xef, 0x78, 0xcc, 0x2b, 0xa1, 0xaf,
	0x97, 0x2e, 0xe4, 0xda, 0x6c, 0x8f, 0x6f, 0xe2, 0xb5, 0x58, 0x99, 0xc1,
	0xc7, 0x05, 0xe2, 0x7d, 0x3f, 0x53, 0x82, 0x3b, 0x80, 0xbd, 0x6a, 0x0a,
	0x5c, 0xd7, 0x5d, 0x91, 0x01, 0xf7, 0xe0, 0x41, 0x9e, 0xf7, 0xf5, 0x71,
	0x6f, 0x74, 0x94, 0x85, 0x62, 0x91, 0x9d, 0xbb, 0x77, 0xb3, 0xbd, 0xad,
	0x8d, 0x70, 0xa9, 0x84, 0x3d, 0x37, 0x4b, 0xf6, 0x48, 0x84, 0xb2, 0x55,
	0xc4, 0xb2, 0x75, 0xa2, 0x6f, 0x3d, 0xe0, 0xe5, 0xde, 0xd3, 0xd4, 0x1b,
	0x30, 0x3d, 0xd8, 0x47, 0xcf, 0xa2, 0xc6, 0x9e, 0xde, 0x6e, 0xc8, 0x8f,
	0x3c, 0xfb, 0x0b, 0x3e, 0x07, 0x16, 0xd6, 0x2c, 0xc3, 0x8b, 0x17, 0x2f,
	0x06, 0x2a, 0x40, 0x08, 0x81, 0x7d, 0xe2, 0x04, 0x03, 0x6f, 0xbe, 0xc9,
	0xed, 0xcb, 0x97, 0x79, 0x9e, 0xcf, 0xb3, 0xd7, 0x30, 0x98, 0xe8, 0xef,
	0x67, 0x53, 0x34, 0x8a, 0x95, 0x8e, 0x32, 0xf7, 0x57, 0x8c, 0x90, 0x02,
	0xb8, 0xb0, 0x50, 0xd6, 0x31, 0xfe, 0xee, 0xe2, 0xfb, 0x85, 0xa3, 0x34,
	0x17, 0xb3, 0xec, 0xef, 0xbd, 0x85, 0x9e, 0x1b, 0x99, 0x7e, 0x00, 0x1f,
	0x3e, 0x80, 0x7e, 0xa0, 0x5c, 0x0d, 0x20, 0xa6, 0x28, 0xca, 0x9c, 0xeb,
	0xba, 0xb5, 0xf5, 0xf5, 0xff, 0x7e, 0xc2, 0x57, 0x7f, 0x54, 0x1e, 0x3a,
	0x76, 0x8c, 0x86, 0xdb, 0xb7, 0xf9, 0xe5, 0xb3, 0xcf, 0xf8, 0xbd, 0xbb,
	0x9b, 0x58, 0x28, 0x44, 0x52, 0xd7, 0x51, 0x1f, 0x2f, 0x30, 0x3e, 0xfe,
	0x0c, 0x67, 0x93, 0xc0, 0x71, 0x5d, 0x42, 0x33, 0x16, 0x4a, 0x5f, 0x3f,
	0xaf, 0x3e, 0xfc, 0x15, 0xa7, 0x58, 0xa0, 0xb0, 0x75, 0xab, 0x75, 0x07,
	0x2e, 0x66, 0xa1, 0x17, 0x78, 0x02, 0xc1, 0xbf, 0x66, 0x31, 0x20, 0x71,
	0xe4, 0xc8, 0x91, 0xf7, 0x5a, 0x5a, 0x5a, 0x3e, 0x05, 0x36, 0x55, 0xb3,
	0xe3, 0x6f, 0xae, 0xeb, 0x62, 0x18, 0x06, 0xd6, 0xfc, 0x3c, 0x35, 0x93,
	0x93, 0x44, 0x66, 0x67, 0xa9, 0x99, 0x9f, 0x47, 0x33, 0x0c, 0x14, 0xcb,
	0xc2, 0xd1, 0x34, 0xcc, 0x50, 0x08, 0x3d, 0x1a, 0xa5, 0x14, 0x8f, 0x53,
	0xda, 0xbe, 0xdd, 0x18, 0xcd, 0xe5, 0xbe, 0x18, 0x1c, 0x1c, 0xfc, 0x06,
	0x18, 0x07, 0xb2, 0x80, 0xe3, 0x07, 0x10, 0x06, 0x92, 0xc0, 0x36, 0xa0,
	0x1e, 0xa8, 0x61, 0xa9, 0x54, 0xd6, 0x6b, 0x0a, 0x10, 0x01, 0x36, 0x57,
	0xf6, 0x68, 0x95, 0x39, 0x00, 0x87, 0xa5, 0x1f, 0x9e, 0xa7, 0x80, 0x0e,
	0x3c, 0x03, 0x66, 0x59, 0xfa, 0x1d, 0x98, 0xaf, 0x66, 0xc0, 0x6b, 0x35,
	0x95, 0x03, 0xc3, 0xab, 0xf8, 0xd7, 0x6b, 0xa2, 0xd2, 0xbd, 0xaf, 0x0f,
	0xb7, 0x02, 0xc4, 0xac, 0x80, 0xd0, 0x7d, 0x3e, 0xfe, 0x01, 0x9f, 0x1e,
	0x98, 0x64, 0x1e, 0x77, 0xb2, 0x47, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
	0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
}
